@@ -3,11 +3,10 @@
 import jieba
 from wordcloud import WordCloud, STOPWORDS
 import matplotlib.pyplot as plt
-def draw_word_cloud(word,sw=''):
+def draw_word_cloud(word):
     words = jieba.cut(word)
     wordstr = " ".join(words)
     sw = set(STOPWORDS)
-    sw.add(sw)
     wc = WordCloud(
         font_path='C:/Windows/Fonts/simhei.ttf',  # 设置字体格式
         max_words=300,
@@ -16,7 +15,7 @@ def draw_word_cloud(word,sw=''):
         background_color='white',
         scale=20,
     ).generate(wordstr)
-    # 显示词云图
+    # 显示词云图 
     plt.imshow(wc.recolor())
     plt.axis("off")
     plt.show()
